import { ValidationError } from 'class-validator';
import { AllowPrimitives } from '../../../../types';
import { iRImageQualityCheck, RImageQualityCheck } from './image-quality-check.model';
import { eCheckResult } from '../../../../consts';
/**
* Short version of structure which is used for storing input image quality check results list
*/
export interface iRImageQuality {
    /**
    * Page index (when working with multi-page document)
    * @type {number}
    */
    pageIndex: number;
    /**
    * Check result
    * @type {eCheckResult}
    */
    checkResult: eCheckResult;
    /**
    * Array of single check result pointers
    * @type {iRImageQualityCheck[]}
    */
    checks: iRImageQualityCheck[];
}
/**
* Short version of structure which is used for storing input image quality check results list
*/
export declare class RImageQuality implements iRImageQuality {
    /**
    * Page index (when working with multi-page document)
    * @type {number}
    */
    pageIndex: number;
    /**
    * Check result
    * @type {eCheckResult}
    */
    checkResult: eCheckResult;
    /**
    * Array of single check result pointers
    * @type {iRImageQualityCheck[]}
    */
    checks: RImageQualityCheck[];
    /**
    * Creates an instance of RImageQuality from plain object
    * @param {AllowPrimitives<iRImageQuality>} input - plain object
    * @returns {RImageQuality}
    */
    static fromPlain: (input: AllowPrimitives<iRImageQuality>) => RImageQuality;
    /**
    * Get validation errors
    * @param {RImageQuality} input - input data
    * @returns {ValidationError[]}
    */
    static getValidationErrors: (input: RImageQuality) => ValidationError[];
    /**
    * Checks if RImageQuality is valid
    * @param {RImageQuality | RImageQuality[]} input - RImageQuality or array of RImageQuality to validate
    * @returns {boolean}
    */
    static isValid: (input: RImageQuality | RImageQuality[]) => boolean;
}
